@@ -15,13 +15,15 @@ class Client(object):
         api_key=None,
         request_timeout=30,
         base_url="https://api.evervault.com/",
-        base_run_url="https://cage.run/",
+        base_run_url="https://run.evervault.com/",
         relay_url="https://relay.evervault.com:443",
+        ca_host="https://ca.evervault.com"
     ):
         self.api_key = api_key
         self.base_url = base_url
         self.base_run_url = base_run_url
         self.relay_url = relay_url
+        self.ca_host = ca_host
         self.request = Request(self.api_key, request_timeout)
         self.crypto_client = CryptoClient()
 
@@ -32,9 +34,9 @@ class Client(object):
     def encrypt(self, data):
         return self.crypto_client.encrypt_data(self, data)
 
-    def run(self, cage_name, encrypted_data, options = { "async": False, "version": None }):
+    def run(self, cage_name, data, options = { "async": False, "version": None }):
         optional_headers = self.__build_cage_run_headers(options)
-        return self.post(cage_name, encrypted_data, optional_headers, True)
+        return self.post(cage_name, data, optional_headers, True)
 
     def encrypt_and_run(self, cage_name, data, options = { "async": False, "version": None }):
         encrypted_data = self.encrypt(data)
@@ -46,6 +48,7 @@ class Client(object):
 
     def relay(client_self, ignore_domains=[]):
         ignore_domains.append(urlparse(client_self.base_run_url).netloc)
+        ignore_domains.append(urlparse(client_self.ca_host).netloc)
         ignore_if_exact = []
         ignore_if_endswith = ()
         for domain in ignore_domains:
@@ -53,16 +56,37 @@ class Client(object):
             ignore_if_exact.append(domain)
             ignore_if_endswith += ('.' + domain, '@' + domain)
         old_request_func = requests.Session.request
-        cert_host = "https://ca.evervault.com"
+
+        ca_content = None
+        i = 0
+
+        while ca_content is None and i < 2:
+            i += 1
+            try:
+                ca_content = requests.get(client_self.ca_host).content
+            except:
+                pass
+
+        if ca_content is None:
+            raise CertDownloadError(f"Unable to install the Evervault root certificate from {client_self.ca_host}. ")
+
         try:
             with tempfile.NamedTemporaryFile(delete=False) as cert_file:
-                cert_file.write(bytes(certifi.contents(), 'ascii') + requests.get(cert_host).content)
+                cert_file.write(bytes(certifi.contents(), 'ascii') + ca_content)
                 cert_path = cert_file.name
         except:
-            raise CertDownloadError(f"Unable to install the Evervault root certficate from {cert_host}. "
+            raise CertDownloadError(f"Unable to install the Evervault root certficate from {client_self.ca_host}. "
                 "Likely a permissions error when attempting to write to the /tmp/ directory.")
         api_key = client_self.api_key
         relay_url = client_self.relay_url
+
+        # We override this method to stop the requests library from
+        # removing the API token from the Proxy-Authorization header
+        def rebuild_proxies(self, prepared_request, proxies):
+          pass
+
+        requests.sessions.SessionRedirectMixin.rebuild_proxies = rebuild_proxies
+
         def new_req_func(self, method, url,
                 params=None, data=None, headers={}, cookies=None, files=None,
                 auth=None, timeout=None, allow_redirects=True, proxies={},
@@ -86,7 +110,7 @@ class Client(object):
                 auth, timeout, allow_redirects, proxies,
                 hooks, stream, verify, cert, json)
         requests.Session.request = new_req_func
- 
+
     def get(self, path, params={}):
         return self.request.make_request("GET", self.__url(path), params)
 
@@ -116,4 +140,4 @@ class Client(object):
                 cage_run_headers['x-version-id'] = str(int(float(options['version'])))
             options.pop('version', None)
         cage_run_headers.update(options)
-        return cage_run_headers
\ No newline at end of file
+        return cage_run_headers
