@@ -7,6 +7,7 @@ from cryptography.hazmat.primitives.ciphers.aead import AESGCM
 from secrets import token_bytes
 import base64
 import time 
+from .version import EV_VERSION
 
 BS = 32
 KEY_INTERVAL = 15
@@ -18,6 +19,7 @@ class Client(object):
         self.generated_ecdh_key = None
         self.shared_key = None
         self.start_time = int(time.time())
+        self.ev_version = self.__base_64_remove_padding(base64.b64encode(bytes(EV_VERSION, "utf8")).decode("utf"))
 
     def encrypt_data(self, fetch, data):
         if data is None:
@@ -95,7 +97,7 @@ class Client(object):
 
     def __format(self, header, iv, public_key, encrypted_payload):
         prefix = f":{header}" if header != "string" else ""
-        return f"ev{prefix}:{self.__base_64_remove_padding(iv)}:{self.__base_64_remove_padding(public_key)}:{self.__base_64_remove_padding(encrypted_payload)}:$"
+        return f"ev:{self.ev_version}{prefix}:{self.__base_64_remove_padding(iv)}:{self.__base_64_remove_padding(public_key)}:{self.__base_64_remove_padding(encrypted_payload)}:$"
 
     def __base_64_remove_padding(self, data):
         return data.rstrip("=")
