@@ -47,3 +47,12 @@ class InvalidPublicKeyError(EvervaultError):
 
 class UnexpectedError(EvervaultError):
     pass
+
+class MissingTeamEcdhKey(EvervaultError):
+    pass
+
+class UnknownEncryptType(EvervaultError):
+    pass
+
+class CertDownloadError(EvervaultError):
+    pass
\ No newline at end of file
